.. QCut documentation master file, created by
   sphinx-quickstart on Mon Jul 22 18:11:00 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

QCut documentation
==================

A package for performing circuit knitting with wire cuts on hardware with no reset-gates or mid-circuit measurements. Built on top of Qiskit.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Usage
   Examples
   Notebooks
   Acknowledgement
   License
   QCut

.. toctree::
   :maxdepth: 1
   
   Changelog